==> kubernetes-model-admissionregistration-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingSpecFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyBindingSpecFluent<A extends ValidatingAdmissionPolicyBindingSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMatchResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public MatchResources getMatchResources();
  public MatchResources buildMatchResources();
  public A withMatchResources(MatchResources matchResources);
  public Boolean hasMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> withNewMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> withNewMatchResourcesLike(MatchResources item);
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editOrNewMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editOrNewMatchResourcesLike(MatchResources item);
  
  /**
   * This method has been deprecated, please use method buildParamRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParamRef getParamRef();
  public ParamRef buildParamRef();
  public A withParamRef(ParamRef paramRef);
  public Boolean hasParamRef();
  public A withNewParamRef(String name,String namespace);
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> withNewParamRef();
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> withNewParamRefLike(ParamRef item);
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editParamRef();
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editOrNewParamRef();
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editOrNewParamRefLike(ParamRef item);
  public String getPolicyName();
  public A withPolicyName(String policyName);
  public Boolean hasPolicyName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MatchResourcesNested<N> extends Nested<N>,MatchResourcesFluent<ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<N>>{
    public N and();
    public N endMatchResources();
    
  }
  public interface ParamRefNested<N> extends Nested<N>,ParamRefFluent<ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<N>>{
    public N and();
    public N endParamRef();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyBindingSpecFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyBindingSpecFluent<A extends ValidatingAdmissionPolicyBindingSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMatchResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public MatchResources getMatchResources();
  public MatchResources buildMatchResources();
  public A withMatchResources(MatchResources matchResources);
  public Boolean hasMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> withNewMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> withNewMatchResourcesLike(MatchResources item);
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editOrNewMatchResources();
  public ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<A> editOrNewMatchResourcesLike(MatchResources item);
  
  /**
   * This method has been deprecated, please use method buildParamRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParamRef getParamRef();
  public ParamRef buildParamRef();
  public A withParamRef(ParamRef paramRef);
  public Boolean hasParamRef();
  public A withNewParamRef(String name,String namespace);
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> withNewParamRef();
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> withNewParamRefLike(ParamRef item);
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editParamRef();
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editOrNewParamRef();
  public ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<A> editOrNewParamRefLike(ParamRef item);
  public String getPolicyName();
  public A withPolicyName(String policyName);
  public Boolean hasPolicyName();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MatchResourcesNested<N> extends Nested<N>,MatchResourcesFluent<ValidatingAdmissionPolicyBindingSpecFluent.MatchResourcesNested<N>>{
    public N and();
    public N endMatchResources();
    
  }
  public interface ParamRefNested<N> extends Nested<N>,ParamRefFluent<ValidatingAdmissionPolicyBindingSpecFluent.ParamRefNested<N>>{
    public N and();
    public N endParamRef();
    
  }
  
}
